pub struct Context(/* private fields */);Expand description
A context represents the runtime data structures and state required by a SYCL backend API to interact with a group of devices associated with a platform.
Implementations
Sourceimpl Context
impl Context
pub fn new(devices: &[&Device]) -> Self
pub fn create_kernel_bundle_from_source( &self, source: &str, ) -> SourceKernelBundle